RenderMorphTargetAllocator

Enum RenderMorphTargetAllocator 

pub enum RenderMorphTargetAllocator {
    Image {
        mesh_id_to_image: HashMap<AssetId<Mesh>, MorphTargetImage>,
    },
    Storage,
}
Stores the images for all morph target displacement data, if the current platform doesn’t support storage buffers.

If the current platform does support storage buffers, the mesh allocator stores displacement data instead.

Variants



Image

The variant used when the current platform doesn’t support storage buffers.

Fields

mesh_id_to_image: HashMap<AssetId<Mesh>, MorphTargetImage>

Maps the ID of each mesh to the image containing its morph target displacements.



Storage

The variant used when the current platform does support storage buffers.

In this case, this resource is empty, because the mesh allocator stores displacements instead.

Implementations

Source

impl RenderMorphTargetAllocator

pub fn allocate( &mut self, render_device: &RenderDevice, render_queue: &RenderQueue, mesh_id: AssetId<Mesh>, targets: &[MorphAttributes], vertex_count: usize, )

Allocates morph target displacements for the given mesh.

If storage buffers aren’t supported on the current platform, this method creates a new MorphTargetImage and stores it inside the allocator.

If storage buffers are supported on the current platform, this method does nothing, as morph target displacements are instead managed by the mesh allocator.

pub fn free(&mut self, mesh_id: AssetId<Mesh>)

Frees the storage associated with morph target displacements for the mesh with the given ID.

If the current platform doesn’t support storage buffers, this drops the reference to the MorphTargetImage that stores the data for the mesh’s morph target displacements. If the current platform does support storage buffers, this method does nothing, as morph target displacements are managed by the mesh allocator in this case.

If passed a mesh without morph targets, this method does nothing.

pub fn get_image(&self, mesh_id: AssetId<Mesh>) -> Option<MorphTargetImage>

Returns the MorphTargetImage containing the packed morph target displacements for the mesh with the given ID, if that image is present.

A MorphTargetImage is only available if storage buffers aren’t supported on the given platform. If storage buffers are supported, this method returns None, as the mesh allocator stores the morph target displacements in that case.