pub struct MorphTargetImage {
pub texture: Texture,
pub texture_view: TextureView,
}Expand description
An image formatted for use with bevy_mesh::morph::MorphWeights for
rendering the morph target, containing the vertex displacements.
We only use these if storage buffers aren’t supported on the current platform. Otherwise, we store the mesh displacements in a storage buffer, managed by the mesh allocator.
Fields
texture: TextureThe texture containing the vertex displacements.
texture_view: TextureViewA view into the texture, suitable for attaching to the vertex shader.
Implementations
Sourceimpl MorphTargetImage
impl MorphTargetImage
Sourcepub fn new(
render_device: &RenderDevice,
render_queue: &RenderQueue,
targets: &[MorphAttributes],
vertex_count: usize,
) -> Result<Self, MorphBuildError>
pub fn new( render_device: &RenderDevice, render_queue: &RenderQueue, targets: &[MorphAttributes], vertex_count: usize, ) -> Result<Self, MorphBuildError>
Generate textures for each morph target.
This accepts an “iterator of MorphAttributes iterators”. Each item
iterated in the top level iterator corresponds “the attributes of a
specific morph target”.
Each pixel of the texture is a component of morph target animated attributes. So a set of 9 pixels is this morph’s displacement for position, normal and tangents of a single vertex (each taking 3 pixels).